@@ -499,6 +499,7 @@ int process_crop(int nb) {
 
 	crop(&gfit, &area);
 	delete_selected_area();
+	reset_display_offset();
 	adjust_cutoff_from_updated_gfit();
 	redraw(com.cvport, REMAP_ALL);
 	redraw_previews();
@@ -882,7 +883,6 @@ int process_resample(int nb) {
 	set_cursor_waiting(TRUE);
 	verbose_resize_gaussian(&gfit, toX, toY, OPENCV_LINEAR);
 	
-	adjust_vport_size_to_image();
 	redraw(com.cvport, REMAP_ALL);
 	redraw_previews();
 	set_cursor_waiting(FALSE);
@@ -2076,23 +2076,30 @@ int process_split(int nb){
 		siril_log_message(_("Siril cannot split layers. Make sure your image is in RGB mode.\n"));
 		return 1;
 	}
-	gchar *R = g_strdup_printf("%s%s", word[1], com.pref.ext);
-	gchar *G = g_strdup_printf("%s%s", word[2], com.pref.ext);
-	gchar *B = g_strdup_printf("%s%s", word[3], com.pref.ext);
 
-	if (gfit.type == DATA_USHORT) {
-		save1fits16(R, &gfit, RLAYER);
-		save1fits16(G, &gfit, GLAYER);
-		save1fits16(B, &gfit, BLAYER);
-	} else {
-		save1fits32(R, &gfit, RLAYER);
-		save1fits32(G, &gfit, GLAYER);
-		save1fits32(B, &gfit, BLAYER);
+	if (get_thread_run()) {
+		PRINT_ANOTHER_THREAD_RUNNING;
+		return 1;
 	}
 
-	g_free(R);
-	g_free(G);
-	g_free(B);
+	struct extract_channels_data *args = malloc(sizeof(struct extract_channels_data));
+	if (args == NULL) {
+		PRINT_ALLOC_ERR;
+		return 1;
+	}
+
+	args->type = 0;
+	args->str_type = _("RGB");
+
+	args->channel[0] = g_strdup_printf("%s%s", word[1], com.pref.ext);
+	args->channel[1] = g_strdup_printf("%s%s", word[2], com.pref.ext);
+	args->channel[2] = g_strdup_printf("%s%s", word[3], com.pref.ext);
+
+	args->fit = calloc(1, sizeof(fits));
+	set_cursor_waiting(TRUE);
+	copyfits(&gfit, args->fit, CP_ALLOC | CP_COPYA | CP_FORMAT, 0);
+	start_in_new_thread(extract_channels, args);
+
 	return 0;
 }
 
@@ -2348,7 +2355,7 @@ int process_seq_split_cfa(int nb) {
 		return 1;
 	}
 
-	struct split_cfa_data *args = malloc(sizeof(struct split_cfa_data));
+	struct split_cfa_data *args = calloc(1, sizeof(struct split_cfa_data));
 
 	args->seq = seq;
 	args->fit = &gfit;
@@ -2394,7 +2401,7 @@ int process_seq_extractHa(int nb) {
 		return 1;
 	}
 
-	struct split_cfa_data *args = malloc(sizeof(struct split_cfa_data));
+	struct split_cfa_data *args = calloc(1, sizeof(struct split_cfa_data));
 
 	args->seq = seq;
 	args->seqEntry = "Ha_";
@@ -2439,7 +2446,7 @@ int process_seq_extractHaOIII(int nb) {
 		return 1;
 	}
 
-	struct split_cfa_data *args = malloc(sizeof(struct split_cfa_data));
+	struct split_cfa_data *args = calloc(1, sizeof(struct split_cfa_data));
 
 	args->seq = seq;
 	args->seqEntry = ""; // not used
@@ -2540,7 +2547,7 @@ int process_convertraw(int nb) {
 					return 1;
 				}
 				if (!g_file_test(value, G_FILE_TEST_EXISTS)) {
-					if (!g_mkdir_with_parents(value, 0755) == 0) {
+					if (g_mkdir_with_parents(value, 0755) < 0) {
 						siril_log_color_message(_("Cannot create output folder: %s\n"), "red", value);
 						return 1;
 					}
@@ -2648,7 +2655,7 @@ int process_link(int nb) {
 					return 1;
 				}
 				if (!g_file_test(value, G_FILE_TEST_EXISTS)) {
-					if (!g_mkdir_with_parents(value, 0755) == 0) {
+					if (g_mkdir_with_parents(value, 0755) < 0) {
 						siril_log_color_message(_("Cannot create output folder: %s\n"), "red", value);
 						return 1;
 					}
@@ -2764,7 +2771,7 @@ int process_convert(int nb) {
 					return 1;
 				}
 				if (!g_file_test(value, G_FILE_TEST_EXISTS)) {
-					if (!g_mkdir_with_parents(value, 0755) == 0) {
+					if (g_mkdir_with_parents(value, 0755) < 0) {
 						siril_log_color_message(_("Cannot create output folder: %s\n"), "red", value);
 						return 1;
 					}
@@ -2883,9 +2890,10 @@ int process_register(int nb) {
 	reg_args->translation_only = FALSE;
 	reg_args->x2upscale = FALSE;
 	reg_args->prefix = "r_";
+	reg_args->min_pairs = AT_MATCH_MINPAIRS;
 
 	/* check for options */
-	for (i = 2; i < 5; i++) {
+	for (i = 2; i < 6; i++) {
 		if (word[i]) {
 			if (!strcmp(word[i], "-drizzle")) {
 				reg_args->x2upscale = TRUE;
@@ -2899,7 +2907,20 @@ int process_register(int nb) {
 					return 1;
 				}
 				reg_args->prefix = strdup(value);
+			} else if (g_str_has_prefix(word[i], "-minpairs=")) {
+				char *current = word[i], *value;
+				value = current + 10;
+				if (value[0] == '\0') {
+					siril_log_message(_("Missing argument to %s, aborting.\n"), current);
+					return 1;
 				}
+				if (atoi(value) < AT_MATCH_MINPAIRS) {
+					siril_log_message(_("%d smaller than minimum allowable star pairs: %d, aborting.\n"),
+						atoi(value), AT_MATCH_MINPAIRS);
+					return 1;
+				}
+				reg_args->min_pairs = atoi(value);
+			}
 		}
 	}
 
