@@ -594,7 +594,7 @@ void on_prepro_button_clicked(GtkButton *button, gpointer user_data) {
 		args->output_seqtype = gtk_combo_box_get_active(output_type);
 		if (args->output_seqtype < 0 || args->output_seqtype > SEQ_FITSEQ)
 			args->output_seqtype = SEQ_REGULAR;
-		args->allow_32bit_output = !com.pref.force_to_16bit || args->output_seqtype != SEQ_SER;
+		args->allow_32bit_output = !com.pref.force_to_16bit && args->output_seqtype != SEQ_SER;
 		set_cursor_waiting(TRUE);
 		control_window_switch_to_tab(OUTPUT_LOGS);
 		start_sequence_preprocessing(args);
@@ -655,7 +655,7 @@ void on_GtkButtonEvaluateCC_clicked(GtkButton *button, gpointer user_data) {
 	/* 1% of cold pixels seems to be a reasonable limit */
 	if (rate > 0.01) {
 		str[0] = g_markup_printf_escaped(_("<span foreground=\"red\">Cold: %ld px</span>"), icold);
-		gtk_widget_set_tooltip_text(widget[0], _("This value may be to high. Please, consider to change sigma value or uncheck the box."));
+		gtk_widget_set_tooltip_text(widget[0], _("This value may be too high. Please, consider to change sigma value or uncheck the box."));
 	}
 	else {
 		str[0] = g_markup_printf_escaped(_("Cold: %ld px"), icold);
@@ -667,7 +667,7 @@ void on_GtkButtonEvaluateCC_clicked(GtkButton *button, gpointer user_data) {
 	/* 1% of hot pixels seems to be a reasonable limit */
 	if (rate > 0.01) {
 		str[1] = g_markup_printf_escaped(_("<span foreground=\"red\">Hot: %ld px</span>"), ihot);
-		gtk_widget_set_tooltip_text(widget[1], _("This value may be to high. Please, consider to change sigma value or uncheck the box."));
+		gtk_widget_set_tooltip_text(widget[1], _("This value may be too high. Please, consider to change sigma value or uncheck the box."));
 	}
 	else {
 		str[1] = g_markup_printf_escaped(_("Hot: %ld px"), ihot);
