@@ -77,6 +77,8 @@ typedef unsigned short WORD;	// default type for internal image data
 
 #define ZOOM_MAX	128
 #define ZOOM_MIN	0.03125
+#define ZOOM_IN		1.5
+#define ZOOM_OUT    1.0 / ZOOM_IN
 #define ZOOM_NONE	1.0
 #define ZOOM_FIT	-1.0	// or any value < 0
 #define ZOOM_DEFAULT	ZOOM_FIT
@@ -547,7 +549,7 @@ struct save_config_struct {
 };
 
 struct pref_struct {
-	gboolean first_use; // use to display information at first use
+	gboolean first_start; // use to display information at first use
 	/* state of window */
 	gboolean remember_windows;
 	rectangle main_w_pos;
@@ -568,6 +570,8 @@ struct pref_struct {
 	save_config save;
 	gboolean show_thumbnails; // show or don't show thumbnails in open dialog box
 	gint thumbnail_size;
+	gboolean check_update; // check update at startup
+	gboolean check_script_version; // check the requires command in scripts
 
 	gint combo_theme;           // value of the combobox theme
 	gchar *combo_lang;           // string value of the combobox lang
@@ -586,6 +590,9 @@ struct pref_struct {
 
 	gboolean force_to_16bit;
 
+	gint selection_guides;	// number of elements of the grid guides (2 for a simple cross, 3 for the 3 thirds rule, etc.)
+
+	gchar *copyright;		// User copyright when saving image as TIFF
 };
 
 /* The global data structure of siril, the only with gfit and the gtk builder,
@@ -600,7 +607,8 @@ struct cominf {
 	int surface_height[MAXVPORT];	// allocated height
 	cairo_surface_t *surface[MAXVPORT];
 	gboolean buf_is_dirty[MAXVPORT];// dirtyness of each buffer (= need to redraw)
-	
+	GdkPixbuf *siril_pix; // Siril.svg image loaded at initialization
+
 	/* Color map */
 	color_map color;
 
@@ -610,7 +618,12 @@ struct cominf {
 	GtkAdjustment *vadj[MAXVPORT];	// adjustments of vport scrollbars
 	sliders_mode sliders;		// 0: min/max, 1: MIPS-LO/HI, 2: user
 	gboolean show_excluded;		// show excluded images in sequences
+
+	cairo_matrix_t display_matrix; // matrix used for image rendering (convert image to display coordinates)
+	cairo_matrix_t image_matrix; // inverse of display_matrix (convert display to image coordinates)
 	double zoom_value;		// 1.0 is normal zoom, use get_zoom_val() to access it
+	point display_offset; // image display offset
+	gboolean translating;		// true we are in display transating mode
 
 	preferences pref; // saved variable in preferences
 
@@ -620,6 +633,7 @@ struct cominf {
 	pointi origin;				// where the selection was originally located
 	gboolean freezeX, freezeY;	// locked axis during modification of a selection 
 	rectangle selection;		// coordinates of the selection rectangle
+	double ratio;				// enforced ratio of the selection (default is 0: none)
 
 	/* alignment preview data */
 	//guchar *preview_buf[PREVIEW_NB];
