@@ -153,7 +153,18 @@ WORD truncate_to_WORD(int x) {
 }
 
 /**
- * Set a float value in the interval given by [low, high]
+ * Clamp an integer value in the interval given by [low, high]
+ * @param val value to be checked
+ * @param low low value of the interval
+ * @param high high value of the interval
+ * @return a new value set in the [low, high] interval
+ */
+int set_int_in_interval(int val, int low, int high) {
+	return max(low, min(val, high));
+}
+
+/**
+ * Clamp a float value in the interval given by [low, high]
  * @param val value to be checked
  * @param low low value of the interval
  * @param high high value of the interval
@@ -164,7 +175,7 @@ float set_float_in_interval(float val, float low, float high) {
 }
 
 /**
- * Set a double value in the interval given by [low, high]
+ * Clamp a double value in the interval given by [low, high]
  * @param val value to be checked
  * @param low low value of the interval
  * @param high high value of the interval
