@@ -442,9 +442,11 @@ char *copy_header(fits *fit) {
 	do {
 		status = 0;
 		fits_movrel_hdu(fit->fptr, 1, &type, &status);
-		if (status || type == IMAGE_HDU)
+		if (status)
 			break;
 		hdu_changed = TRUE;
+		if (type == IMAGE_HDU)
+			break;
 		siril_debug_print("header read from another HDU (CHDU changed)\n");
 		if (copy_header_from_hdu(fit->fptr, &header, &strsize, &strlength))
 			break;
@@ -542,6 +544,8 @@ static void convert_data_float(int bitpix, const void *from, float *to, size_t n
 	int16_t *data16;
 	double *pixels_double;
 	long *sdata32;	// TO BE TESTED on 32-bit arch, seems to be a cfitsio bug
+	long mini = LONG_MAX;
+	long maxi = -LONG_MAX;
 	unsigned long *data32;
 	float *data32f;
 
@@ -567,13 +571,21 @@ static void convert_data_float(int bitpix, const void *from, float *to, size_t n
 			break;
 		case ULONG_IMG:		// 32-bit unsigned integer pixels
 			data32 = (unsigned long *)from;
+			for (i = 0; i < nbdata; i++) {
+				mini = min(data32[i], mini);
+				maxi = max(data32[i], maxi);
+			}
 			for (i = 0; i < nbdata; i++)
-				to[i] = (float)data32[i] / 4294967295;
+				to[i] = (float)((data32[i] - mini)) / (maxi - mini);
 			break;
 		case LONG_IMG:		// 32-bit signed integer pixels
 			sdata32 = (long *)from;
+			for (i = 0; i < nbdata; i++) {
+				mini = min(sdata32[i], mini);
+				maxi = max(sdata32[i], maxi);
+			}
 			for (i = 0; i < nbdata; i++)
-				to[i] = (float)((sdata32[i] + 2147483647)) / 4294967295; // 2147483647 is bzero
+				to[i] = (float)((sdata32[i] - mini)) / (maxi - mini);
 			break;
 		case FLOAT_IMG:		// 32-bit floating point pixels, we use it only if float is not in the [0, 1] range
 			data32f = (float *)from;
@@ -2243,34 +2255,6 @@ void fit_debayer_buffer(fits *fit, void *newbuf) {
 	}
 }
 
-/* In-place conversion to one channel.
- * See copyfits with CP_EXTRACT for the same in a new fits */
-void keep_first_channel_from_fits(fits *fit) {
-	if (fit->naxis == 1)
-		return;
-	fit->naxis = 2;
-	fit->naxes[2] = 1;
-	size_t nbdata = fit->naxes[0] * fit->naxes[1];
-	if (fit->type == DATA_USHORT) {
-		fit->data = realloc(fit->data, nbdata * sizeof(WORD));
-		fit->pdata[RLAYER] = fit->data;
-		fit->pdata[GLAYER] = fit->data;
-		fit->pdata[BLAYER] = fit->data;
-	}
-	else if (fit->type == DATA_FLOAT) {
-		fit->fdata = realloc(fit->fdata, nbdata * sizeof(float));
-		fit->fpdata[RLAYER] = fit->fdata;
-		fit->fpdata[GLAYER] = fit->fdata;
-		fit->fpdata[BLAYER] = fit->fdata;
-	}
-	if (fit->maxi > 0.0) {
-		if (fit->maxi != fit_get_max(fit, RLAYER))
-			fit->maxi = 0.0;
-		if (fit->mini != fit_get_min(fit, RLAYER))
-			fit->mini = 0.0;
-	}
-}
-
 static void gray2rgb(float gray, guchar *rgb) {
 	*rgb++ = (guchar) round_to_BYTE(255. * gray);
 	*rgb++ = (guchar) round_to_BYTE(255. * gray);
