@@ -76,6 +76,8 @@ void free_image_data() {
 		clear_sampling_setting_box();	// clear focal and pixel pitch info
 		free_background_sample_list(com.grad_samples);
 		com.grad_samples = NULL;
+		reset_display_offset();
+		reset_zoom_default();
 	}
 	clear_histograms();
 
@@ -258,7 +260,6 @@ void open_single_image_from_gfit() {
 
 	close_tab();
 	update_gfit_histogram_if_needed();
-	adjust_vport_size_to_image();
 	redraw(com.cvport, REMAP_ALL);
 	
 }
