@@ -50,6 +50,7 @@
 #include "core/signals.h"
 #include "core/siril_app_dirs.h"
 #include "core/siril_language.h"
+#include "core/siril_update.h"
 #include "core/OS_utils.h"
 #include "algos/star_finder.h"
 #include "algos/photometry.h"
@@ -125,6 +126,8 @@ static GActionEntry app_entries[] = {
 	{ "plot", tab_plot_activate },
 	{ "stacking", tab_stacking_activate },
 	{ "logs", tab_logs_activate },
+	{ "zoom_out", zoom_out_activate },
+	{ "zoom_in", zoom_in_activate },
 	{ "hide_show_toolbar", toolbar_activate }
 };
 
@@ -162,6 +165,8 @@ static void global_initialization() {
 	/* initialize the com struct and zoom level */
 	com.sliders = MINMAX;
 	com.zoom_value = ZOOM_DEFAULT;
+	com.ratio = 0.0;
+	com.siril_pix = NULL;
 }
 
 static void init_num_procs() {
@@ -234,13 +239,10 @@ static void siril_app_activate(GApplication *application) {
 	initialize_stacking_default();
 
 	/* we also initialize a couple of important variables */
-	com.pref.first_use = TRUE;
 	com.pref.stack.mem_mode = 0;
 	com.pref.stack.memory_ratio = 0.9;
 	com.pref.stack.memory_amount = 4.0;
-	com.pref.show_thumbnails = TRUE;
 	com.pref.thumbnail_size = 256;
-	com.pref.remember_windows = TRUE;
 	com.pref.ext = g_strdup(".fit");
 	com.pref.force_to_16bit = FALSE;
 	com.pref.swap_dir = g_strdup(g_get_tmp_dir());
@@ -315,6 +317,11 @@ static void siril_app_activate(GApplication *application) {
 		gtk_window_set_application(GTK_WINDOW(lookup_widget("control_window")),	GTK_APPLICATION(application));
 		/* Load state of the main windows (position and maximized) */
 		load_main_window_state();
+		/* Check for update */
+#ifdef HAVE_LIBCURL
+		if (com.pref.check_update)
+			siril_check_updates(FALSE);
+#endif
 #if 0 //we need to think about it
 		/* see https://gitlab.gnome.org/GNOME/gtk/issues/2342 */
 		NSEvent *focusevent;
