@@ -178,39 +178,39 @@ static int star_align_prepare_hook(struct generic_seq_args *args) {
 			PRINT_ALLOC_ERR;
 			return 1;
 		}
-	}
 
-	if (args->seq->type == SEQ_SER) {
-		/* copied from seq_prepare_hook with one variation */
-		args->new_ser = malloc(sizeof(struct ser_struct));
-		if (!args->new_ser) {
-			PRINT_ALLOC_ERR;
-			return 1;
+		if (args->seq->type == SEQ_SER) {
+			/* copied from seq_prepare_hook with one variation */
+			args->new_ser = malloc(sizeof(struct ser_struct));
+			if (!args->new_ser) {
+				PRINT_ALLOC_ERR;
+				return 1;
+			}
+
+			char dest[256];
+			const char *ptr = strrchr(args->seq->seqname, G_DIR_SEPARATOR);
+			if (ptr)
+				snprintf(dest, 255, "%s%s.ser", regargs->prefix, ptr + 1);
+			else
+				snprintf(dest, 255, "%s%s.ser", regargs->prefix, args->seq->seqname);
+
+			/* Here the last argument is NULL because we do not want copy SER file
+			 * from the original. Indeed in the demosaicing case this would lead to
+			 * a wrong file (B&W and not in RAW data). Moreover, header informations
+			 * (like fps, local and UTC time, ...) have no sense now since some frames
+			 * could be removed from the sequence.
+			 */
+			if (ser_create_file(dest, args->new_ser, TRUE, NULL)) {
+				free(args->new_ser);
+				args->new_ser = NULL;
+				return 1;
+			}
 		}
-
-		char dest[256];
-		const char *ptr = strrchr(args->seq->seqname, G_DIR_SEPARATOR);
-		if (ptr)
-			snprintf(dest, 255, "%s%s.ser", regargs->prefix, ptr + 1);
-		else
-			snprintf(dest, 255, "%s%s.ser", regargs->prefix, args->seq->seqname);
-
-		/* Here the last argument is NULL because we do not want copy SER file
-		 * from the original. Indeed in the demosaicing case this would lead to
-		 * a wrong file (B&W and not in RAW data). Moreover, header informations
-		 * (like fps, local and UTC time, ...) have no sense now since some frames
-		 * could be removed from the sequence.
-		 */
-		if (ser_create_file(dest, args->new_ser, TRUE, NULL)) {
-			free(args->new_ser);
-			args->new_ser = NULL;
-			return 1;
+		else if (args->seq->type == SEQ_FITSEQ) {
+			if (seq_prepare_hook(args))
+				return 1;
 		}
-	}
-	else if (args->seq->type == SEQ_FITSEQ) {
-		if (seq_prepare_hook(args))
-			return 1;
-	}
+}
 
 	sadata->success = calloc(args->nb_filtered_images, sizeof(BYTE));
 	if (!sadata->success) {
@@ -285,6 +285,12 @@ static int star_align_image_hook(struct generic_seq_args *args, int out_index, i
 			free_fitted_stars(stars);
 			return 1;
 		}
+		if (H.pair_matched < regargs->min_pairs) {
+			siril_log_color_message(_("Not enough star pairs (%d): Image %d skipped\n"),
+					"red", H.pair_matched, filenum);
+			free_fitted_stars(stars);
+			return 1;
+		}
 
 		FWHM_average(stars, nbpoints, &FWHMx, &FWHMy, &units);
 #ifdef _OPENMP
@@ -352,30 +358,21 @@ static int star_align_finalize_hook(struct generic_seq_args *args) {
 				failed++;
 		regargs->new_total = args->nb_filtered_images - failed;
 
-		// regargs->imgparam and regargs->regparam may have holes caused by images
-		// that failed to be registered
-		if (failed && !regargs->translation_only) {
-			int j;
-			for (i = 0, j = 0; i < regargs->new_total; i++, j++) {
-				while (!sadata->success[j] && j < args->nb_filtered_images) j++;
-				g_assert(sadata->success[j]);
-				if (i != j) {
-					regargs->imgparam[i] = regargs->imgparam[j];
-					regargs->regparam[i] = regargs->regparam[j];
+		if (!regargs->translation_only) {
+			if (failed) {
+				// regargs->imgparam and regargs->regparam may have holes caused by images
+				// that failed to be registered - compact them
+				int j;
+				for (i = 0, j = 0; i < regargs->new_total; i++, j++) {
+					while (!sadata->success[j] && j < args->nb_filtered_images) j++;
+					g_assert(sadata->success[j]);
+					if (i != j) {
+						regargs->imgparam[i] = regargs->imgparam[j];
+						regargs->regparam[i] = regargs->regparam[j];
+					}
 				}
 			}
-			// compact the sequence: there will be holes for images
-			// that failed to be registered if we don't do that
-			if (args->seq->type == SEQ_SER)
-				ser_compact_file(args->new_ser, sadata->success, args->nb_filtered_images);
-		}
 
-		// same as ser_finalize_hook()
-		if (args->seq->type == SEQ_SER) {
-			ser_write_and_close(args->new_ser);
-			free(args->new_ser);
-		}
-		else if (args->seq->type == SEQ_FITSEQ) {
 			seq_finalize_hook(args);
 		}
 	} else {
@@ -384,11 +381,12 @@ static int star_align_finalize_hook(struct generic_seq_args *args) {
 		args->seq->regparam[regargs->layer] = NULL;
 
 		// args->new_ser can be null if stars were not detected in the reference image
-		if (args->seq->type == SEQ_SER && args->new_ser) {
+		// same as seq_finalize_hook but with file deletion
+		if ((args->force_ser_output || args->seq->type == SEQ_SER) && args->new_ser) {
 			ser_close_and_delete_file(args->new_ser);
 			free(args->new_ser);
 		}
-		else if (args->seq->type == SEQ_FITSEQ && args->new_fitseq) {
+		else if ((args->force_fitseq_output || args->seq->type == SEQ_FITSEQ) && args->new_fitseq) {
 			fitseq_close_and_delete_file(args->new_fitseq);
 			free(args->new_fitseq);
 		}
